@@ -1,6 +1,5 @@
 # Python modules
 import time
-import sys
 import hashlib
 
 # 3rd party modules
@@ -9,8 +8,6 @@ import sysv_ipc
 # Utils for this demo
 import utils
 
-PY_MAJOR_VERSION = sys.version_info[0]
-
 utils.say("Oooo 'ello, I'm Mrs. Premise!")
 
 params = utils.read_params()
@@ -42,8 +39,7 @@ for i in range(0, params["ITERATIONS"]):
 
     # What I read must be the md5 of what I wrote or something's
     # gone wrong.
-    if PY_MAJOR_VERSION > 2:
-        what_i_sent = what_i_sent.encode()
+    what_i_sent = what_i_sent.encode()
     try:
         assert(s == hashlib.md5(what_i_sent).hexdigest())
     except AssertionError:
